@@ -20,9 +20,14 @@ point_in_polygon <- function(x, polygon) {
   inside <- FALSE
 
   for (i in seq_len(n)) {
-    if (((polygon$y[i] >= point$y) != (polygon$y[j] >= point$y)) &&
-        (point$x <= (polygon$x[j] - polygon$x[i])*(point$y - polygon$y[i]) /
-         (polygon$y[j] - polygon$y[i]) + polygon$x[i])) {
+    if (
+      ((polygon$y[i] >= point$y) != (polygon$y[j] >= point$y)) &&
+        (point$x <=
+          (polygon$x[j] - polygon$x[i]) *
+            (point$y - polygon$y[i]) /
+            (polygon$y[j] - polygon$y[i]) +
+            polygon$x[i])
+    ) {
       inside <- !inside
     }
 
@@ -31,4 +36,3 @@ point_in_polygon <- function(x, polygon) {
 
   inside
 }
-
